# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import zarban.service.openapi_client
from zarban.service.openapi_client.api.staking_api import StakingApi  # noqa: E501
from zarban.service.openapi_client.rest import ApiException


class TestStakingApi(unittest.TestCase):
    """StakingApi unit test stubs"""

    def setUp(self):
        self.api = zarban.service.openapi_client.api.staking_api.StakingApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_collect_staking_reward(self):
        """Test case for collect_staking_reward

        Collect staking reward  # noqa: E501
        """
        pass

    def test_get_staking_plans(self):
        """Test case for get_staking_plans

        Get staking plans  # noqa: E501
        """
        pass

    def test_get_user_staking_stats(self):
        """Test case for get_user_staking_stats

        Get user staking stats  # noqa: E501
        """
        pass

    def test_stake_to_staking_contract(self):
        """Test case for stake_to_staking_contract

        Stake to staking contract  # noqa: E501
        """
        pass

    def test_withdraw_staked_asset(self):
        """Test case for withdraw_staked_asset

        Withdraw staked asset  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
