# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import zarban.service.openapi_client
from zarban.service.openapi_client.api.stable_coin_system_api import StableCoinSystemApi  # noqa: E501
from zarban.service.openapi_client.rest import ApiException


class TestStableCoinSystemApi(unittest.TestCase):
    """StableCoinSystemApi unit test stubs"""

    def setUp(self):
        self.api = zarban.service.openapi_client.api.stable_coin_system_api.StableCoinSystemApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_approve_and_join_zar_transaction(self):
        """Test case for approve_and_join_zar_transaction

        approve and join ZAR token into Vat contract  # noqa: E501
        """
        pass

    def test_create_stable_coin_vault(self):
        """Test case for create_stable_coin_vault

        Create vault  # noqa: E501
        """
        pass

    def test_deposit_stable_coin_collateral(self):
        """Test case for deposit_stable_coin_collateral

        Deposit collateral  # noqa: E501
        """
        pass

    def test_exit_gem_transaction(self):
        """Test case for exit_gem_transaction

        exit Gem token (which can be used as collateral) from Vat contract  # noqa: E501
        """
        pass

    def test_exit_zar_transaction(self):
        """Test case for exit_zar_transaction

        exit ZAR token from Vat contract  # noqa: E501
        """
        pass

    def test_get_all_ilks(self):
        """Test case for get_all_ilks

        Get all Ilks  # noqa: E501
        """
        pass

    def test_get_collector_data(self):
        """Test case for get_collector_data

        Get collector data  # noqa: E501
        """
        pass

    def test_get_ilk_by_name(self):
        """Test case for get_ilk_by_name

        Get Ilk by name  # noqa: E501
        """
        pass

    def test_get_vault_by_id(self):
        """Test case for get_vault_by_id

        Get a vault by ID  # noqa: E501
        """
        pass

    def test_get_vault_events_by_id(self):
        """Test case for get_vault_events_by_id

        Get vault events by ID  # noqa: E501
        """
        pass

    def test_get_vaults_by_owner(self):
        """Test case for get_vaults_by_owner

        Get vaults by owner query  # noqa: E501
        """
        pass

    def test_liquidate_vault_transaction(self):
        """Test case for liquidate_vault_transaction

        liquidate a vault  # noqa: E501
        """
        pass

    def test_mint_zar_transaction(self):
        """Test case for mint_zar_transaction

        Mint ZAR  # noqa: E501
        """
        pass

    def test_repay_zar_transaction(self):
        """Test case for repay_zar_transaction

        Repay ZAR  # noqa: E501
        """
        pass

    def test_reset_auction_transaction(self):
        """Test case for reset_auction_transaction

        reset a auction  # noqa: E501
        """
        pass

    def test_take_auction_transaction(self):
        """Test case for take_auction_transaction

        take a auction  # noqa: E501
        """
        pass

    def test_withdraw_collateral_transaction(self):
        """Test case for withdraw_collateral_transaction

        Withdraw collateral  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
