# coding: utf-8

"""
    Zarban API

    API for Zarban services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import zarban.service.openapi_client
from zarban.service.openapi_client.models.user_borrows_response import UserBorrowsResponse  # noqa: E501
from zarban.service.openapi_client.rest import ApiException

class TestUserBorrowsResponse(unittest.TestCase):
    """UserBorrowsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserBorrowsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = zarban.service.openapi_client.models.user_borrows_response.UserBorrowsResponse()  # noqa: E501
        if include_optional :
            return UserBorrowsResponse(
                data = [
                    zarban.service.openapi_client.models.lendingpool_borrow.LendingpoolBorrow(
                        user = '0', 
                        underlying_asset = zarban.service.openapi_client.models.token.Token(
                            name = 'Zar Stablecoin', 
                            symbol = 'USD', 
                            decimals = 18, 
                            address = '0x1234567890123456789012345678901234567890', 
                            logo_uri = '/assets/logos/dai.svg', 
                            chain_id = 1, 
                            persian_name = 'زر', ), 
                        amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        borrow_rate = '0', 
                        max_borrow_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, )
                    ]
            )
        else :
            return UserBorrowsResponse(
                data = [
                    zarban.service.openapi_client.models.lendingpool_borrow.LendingpoolBorrow(
                        user = '0', 
                        underlying_asset = zarban.service.openapi_client.models.token.Token(
                            name = 'Zar Stablecoin', 
                            symbol = 'USD', 
                            decimals = 18, 
                            address = '0x1234567890123456789012345678901234567890', 
                            logo_uri = '/assets/logos/dai.svg', 
                            chain_id = 1, 
                            persian_name = 'زر', ), 
                        amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, 
                        borrow_rate = '0', 
                        max_borrow_amount = {"USD":"1.23","TMN":"45.67","ZAR":"89.01","ETH":"0.02"}, )
                    ],
        )

    def testUserBorrowsResponse(self):
        """Test UserBorrowsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
