# coding: utf-8

"""
    Zarban Wallet API

    API for Zarban wallet services.  # noqa: E501

    The version of the OpenAPI document: 2.0.0
    Contact: info@zarban.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import zarban.wallet.openapi_client
from zarban.wallet.openapi_client.api.auth_api import AuthApi  # noqa: E501
from zarban.wallet.openapi_client.rest import ApiException


class TestAuthApi(unittest.TestCase):
    """AuthApi unit test stubs"""

    def setUp(self):
        self.api = zarban.wallet.openapi_client.api.auth_api.AuthApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_authenticate_with_telegram(self):
        """Test case for authenticate_with_telegram

        Authenticate with Telegram  # noqa: E501
        """
        pass

    def test_generate_jwt_token(self):
        """Test case for generate_jwt_token

        Generate a JWT token  # noqa: E501
        """
        pass

    def test_get_otp(self):
        """Test case for get_otp

        Get OTP  # noqa: E501
        """
        pass

    def test_login_with_email_and_password(self):
        """Test case for login_with_email_and_password

        Login with email and password  # noqa: E501
        """
        pass

    def test_signup_with_email_and_password(self):
        """Test case for signup_with_email_and_password

        signup with email and password  # noqa: E501
        """
        pass

    def test_verify_user_email(self):
        """Test case for verify_user_email

        Verify email  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
